
### General template for a pymol script
### Run this script and study the output images before you modify it
### By Dr. Williams, Chen 4511/6501

#----do not edit between the dashed lines----------VVVV-----------------------------

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# low quality surfaces (or too slow)
set surface_quality, 1
set_color lightwheat, [1.00,0.92,0.75]
#----do not edit between the dashed lines----------^^^^-----------------------------

### Hydrogen atoms were added 3bow with Molprobity
### 
load files/3bowFH.pdb, calpain_rib

create calpain_stick, calpain_rib

### show calpain_stick as sticks and color it
### by atom type
hide everything, calpain_stick
show sticks, calpain_stick
color red, name O* and calpain_stick
color wheat, name C* and calpain_stick
color blue, name N* and calpain_stick
color yellow, name P* and calpain_stick
color yellow, name S* and calpain_stick

### The catalytic triad
### this is a Cys105Ser mutant, so the HB distances are not optimum
create triad, (resi 105+262+286) and (calpain_rib and chain A)
hide everything, triad
show sticks, triad
color magenta, triad
color red, name O* and triad
color magenta, name C* and triad
color blue, name N* and triad
color grey90, name H* and triad
color yellow, name OG and triad

distance hbond_triad, (triad and resi 286 and name O*), (triad and resi 262 and name H*), 2.3
distance hbond_triad, (triad and resi 262 and name N*), (triad and resi 105 and name H*), 2.9
# set the font of object dist_object
set label_font_id=3, hbond_triad
# set the dash width
set dash_width=3.5, hbond_triad
# set the dash gap
set dash_gap, 0.4
# set the dash length
set dash_length, .01
# set the color
color yellow, hbond_triad

### show calpain_rib as a ribbon diagram and color it
### by secondary structure
hide everything, calpain_rib
show cartoon, calpain_rib
color blue, calpain_rib
### color red, ss h and calpain_rib
### color yellow, ss s and calpain_rib
### color green, ss l+'' and calpain_rib

create CAST_rib, chain C
hide everything, CAST_rib
show cartoon, CAST_rib
color yellow, CAST_rib
color deeppurple, (resi 620 or resi 621) and CAST_rib

create CAST_sticks, CAST_rib
hide everything, CAST_sticks
show sticks, CAST_sticks
color red, name O* and CAST_sticks
color grey80,  name H* and CAST_sticks
color wheat, name C* and CAST_sticks
color blue, name N* and CAST_sticks
color yellow, name P* and CAST_sticks
color yellow, name S* and CAST_sticks
show sphere, CAST_sticks and resi 612 and name C
set sphere_scale,  0.3, CAST_sticks
color deeppurple, name C* and (resi 620 or resi 621) and CAST_sticks

create CAST_surface, CAST_sticks
hide everything, CAST_surface
show surface, CAST_surface
enable CAST_surface
disable CAST_surface
color deeppurple, (resi 620 or resi 621) and CAST_surface

create pocket_surface, byres(calpain_rib within 4 of CAST_rib)
remove (pocket_surface within .1 of CAST_rib)
color salmon, name O* and pocket_surface
color lightwheat, name C* and pocket_surface
color white, name H* and pocket_surface
color lightblue, name N* and pocket_surface
color yellow, name P* and pocket_surface
color yellow, name S* and pocket_surface
hide everything, pocket_surface
show surface, pocket_surface
enable, pocket_surface
disable, pocket_surface

### DO NOT EDIT
### this command will create a second object (pocket_sticks) containing
### the amino acids that are in contact with the 
### ligand and will show it in stick
create pocket_sticks, pocket_surface
hide everything, pocket_sticks
show sticks, pocket_sticks

## create di_pro, resn pro and (resi 620 or resi 621) and chain C
## hide everything, di_pro
## show sticks, di_pro

###  draw hydrogen bonds between CAST_sticks and pocket_sticks
distance hbond1, (CAST_sticks and (name N* or name O*)), (pocket_sticks and name H*), 2.3
distance hbond1, (CAST_sticks and name H*), (pocket_sticks and (name N* or name O*)), 2.3
# set the font of object dist_object
set label_font_id=7, hbond1
# set the dash width
set dash_width=3.5, hbond1
# set the color
color black, hbond1

disable all,
enable calpain_rib
enable triad
enable hbond_triad

### set the global view
set_view (\
     0.959507406,    0.265151531,    0.095055975,\
    -0.253437161,    0.665388227,    0.702150881,\
     0.122932076,   -0.697813928,    0.705647349,\
     0.000029525,   -0.000081707,  -33.968173981,\
     7.551394939,   22.306892395,   25.395475388,\
    29.509922028,   38.367359161,  -20.000000000 )
